WebView

Struct WebView 

pub struct WebView { /* private fields */ }
A webview based on wry WebView.

[experimental]

Implementations

Source

impl WebView

pub fn new(webview: WebView, _: &mut Window, cx: &mut App) -> Self

Create a new WebView from a wry WebView.

pub fn show(&mut self)

Show the webview.

pub fn hide(&mut self)

Hide the webview.

pub fn visible(&self) -> bool

Get whether the webview is visible.

pub fn bounds(&self) -> Bounds<Pixels>

Get the current bounds of the webview.

pub fn back(&mut self) -> Result<()>

Go back in the webview history.

pub fn load_url(&mut self, url: &str)

Load a URL in the webview.

pub fn raw(&self) -> &WebView

Get the raw wry webview.

Methods from Deref<Target = WebView>

pub fn id(&self) -> &str

Returns the id of this webview.

pub fn url(&self) -> Result<String, Error>

Get the current url of the webview

pub fn evaluate_script(&self, js: &str) -> Result<(), Error>

Evaluate and run javascript code.

pub fn evaluate_script_with_callback( &self, js: &str, callback: impl Fn(String) + Send + 'static, ) -> Result<(), Error>

Evaluate and run javascript code with callback function. The evaluation result will be serialized into a JSON string and passed to the callback function.

Exception is ignored because of the limitation on windows. You can catch it yourself and return as string as a workaround.

  • ** Android:** Not implemented yet.
pub fn print(&self) -> Result<(), Error>

Launch print modal for the webview content.

pub fn cookies_for_url(&self, url: &str) -> Result<Vec<Cookie<'static>>, Error>

Get a list of cookies for specific url.

pub fn cookies(&self) -> Result<Vec<Cookie<'static>>, Error>

Get the list of cookies.

Platform-specific
  • Android: Unsupported, always returns an empty Vec.

Set a cookie for the webview.

Platform-specific
  • Android: Not supported.

Delete a cookie for the webview.

Platform-specific
  • Android: Not supported.
pub fn open_devtools(&self)

Open the web inspector which is usually called dev tool.

Platform-specific
  • Android / iOS: Not supported.
pub fn close_devtools(&self)

Close the web inspector which is usually called dev tool.

Platform-specific
  • Windows / Android / iOS: Not supported.
pub fn is_devtools_open(&self) -> bool

Gets the devtool window’s current visibility state.

Platform-specific
  • Windows / Android / iOS: Not supported.
pub fn zoom(&self, scale_factor: f64) -> Result<(), Error>

Set the webview zoom level

Platform-specific:
  • Android: Not supported.
  • macOS: available on macOS 11+ only.
  • iOS: available on iOS 14+ only.
pub fn set_background_color( &self, background_color: (u8, u8, u8, u8), ) -> Result<(), Error>

Specify the webview background color.

The color uses the RGBA format.

Platfrom-specific:
  • macOS: Not implemented.
  • Windows:
    • On Windows 7, transparency is not supported and the alpha value will be ignored.
    • On Windows higher than 7: translucent colors are not supported so any alpha value other than 0 will be replaced by 255
pub fn load_url(&self, url: &str) -> Result<(), Error>

Navigate to the specified url

pub fn reload(&self) -> Result<(), Error>

Reloads the current page.

pub fn load_url_with_headers( &self, url: &str, headers: HeaderMap, ) -> Result<(), Error>

Navigate to the specified url using the specified headers

pub fn load_html(&self, html: &str) -> Result<(), Error>

Load html content into the webview

pub fn clear_all_browsing_data(&self) -> Result<(), Error>

Clear all browsing data

pub fn bounds(&self) -> Result<Rect, Error>

pub fn set_bounds(&self, bounds: Rect) -> Result<(), Error>

Set the webview bounds.

This is only effective if the webview was created as a child or created using [WebViewBuilderExtUnix::new_gtk] with gtk::Fixed.

pub fn set_visible(&self, visible: bool) -> Result<(), Error>

Shows or hides the webview.

pub fn focus(&self) -> Result<(), Error>

Try moving focus to the webview.

pub fn focus_parent(&self) -> Result<(), Error>

Try moving focus away from the webview back to the parent window.

Platform-specific:
  • Android: Not implemented.