pub struct WebViewHandle(/* private fields */);Expand description
An owned, UI-thread-local handle to the raw wry webview.
Cloning this handle prolongs the native webview’s lifetime. Dropping the owning WebView
entity hides the child view, but final native destruction waits until all handle and frame
clones are dropped. All handles must be dropped before the parent window is destroyed.
Implementations